package com.ruoyi.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.plant.mapper.TCanteenCardMapper;
import com.ruoyi.plant.domain.TCanteenCard;
import com.ruoyi.plant.service.ITCanteenCardService;

/**
 * 员工卡管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@Service
public class TCanteenCardServiceImpl implements ITCanteenCardService 
{
    @Autowired
    private TCanteenCardMapper tCanteenCardMapper;

    /**
     * 查询员工卡管理
     * 
     * @param cardId 员工卡管理主键
     * @return 员工卡管理
     */
    @Override
    public TCanteenCard selectTCanteenCardByCardId(Long cardId)
    {
        return tCanteenCardMapper.selectTCanteenCardByCardId(cardId);
    }

    /**
     * 查询员工卡管理列表
     * 
     * @param tCanteenCard 员工卡管理
     * @return 员工卡管理
     */
    @Override
    public List<TCanteenCard> selectTCanteenCardList(TCanteenCard tCanteenCard)
    {
        return tCanteenCardMapper.selectTCanteenCardList(tCanteenCard);
    }

    /**
     * 新增员工卡管理
     * 
     * @param tCanteenCard 员工卡管理
     * @return 结果
     */
    @Override
    public int insertTCanteenCard(TCanteenCard tCanteenCard)
    {
        return tCanteenCardMapper.insertTCanteenCard(tCanteenCard);
    }

    /**
     * 修改员工卡管理
     * 
     * @param tCanteenCard 员工卡管理
     * @return 结果
     */
    @Override
    public int updateTCanteenCard(TCanteenCard tCanteenCard)
    {
        return tCanteenCardMapper.updateTCanteenCard(tCanteenCard);
    }

    /**
     * 批量删除员工卡管理
     * 
     * @param cardIds 需要删除的员工卡管理主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenCardByCardIds(Long[] cardIds)
    {
        return tCanteenCardMapper.deleteTCanteenCardByCardIds(cardIds);
    }

    /**
     * 删除员工卡管理信息
     * 
     * @param cardId 员工卡管理主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenCardByCardId(Long cardId)
    {
        return tCanteenCardMapper.deleteTCanteenCardByCardId(cardId);
    }
}
